/**
 * TCS Dependency Map Renderer
 *
 * Copyright (c) 2005 TopCoder, Inc. All rights Reserved.
 */
package com.topcoder.rules.dependencymap.view;

import com.topcoder.util.errorhandling.BaseException;

/**
 * This class represents an exception that is thrown during the rendering process and will contain a reason and
 * potentially an embedded exception.
 *
 * @author Pops
 * @author TCSDeveloper
 */
public class RendererException extends BaseException {

    /**
     * Creates the exception by calling the super constructor with the same parameter.
     *
     * @param reason The reason for the exception
     * @throws NullPointerException if reason is null
     * @throws IllegalArgumentException if reason is empty (trim'd)
     */
    public RendererException(String reason) {
        super(reason);
        if (reason == null) {
            throw new NullPointerException("reason should not be null.");
        }
        if (reason.trim().length() == 0) {
            throw new IllegalArgumentException("reason should not be empty.");
        }
    }

    /**
     * Creates the exception by calling the super constructor with the same parameters.
     *
     * @param reason The reason for the exception
     * @param cause A, potentially null, related exception that caused it
     * @throws NullPointerException if reason is null
     * @throws IllegalArgumentException if reason is empty (trim'd)
     */
    public RendererException(String reason, Exception cause) {
        super(reason, cause);
        if (reason == null) {
            throw new NullPointerException("reason should not be null.");
        }
        if (reason.trim().length() == 0) {
            throw new IllegalArgumentException("reason should not be empty.");
        }
        if (cause == null) {
            throw new NullPointerException("cause should not be null.");
        }
    }

}
